@@ -48,11 +48,11 @@ use std::path::Path;
 
 pub fn init<P: NetPermissions + 'static>() -> Vec<OpPair> {
   vec![
-    ("op_accept", op_async(op_accept)),
-    ("op_connect", op_async(op_connect::<P>)),
-    ("op_listen", op_sync(op_listen::<P>)),
-    ("op_datagram_receive", op_async(op_datagram_receive)),
-    ("op_datagram_send", op_async(op_datagram_send::<P>)),
+    ("op_net_accept", op_async(op_net_accept)),
+    ("op_net_connect", op_async(op_net_connect::<P>)),
+    ("op_net_listen", op_sync(op_net_listen::<P>)),
+    ("op_dgram_recv", op_async(op_dgram_recv)),
+    ("op_dgram_send", op_async(op_dgram_send::<P>)),
     ("op_dns_resolve", op_async(op_dns_resolve::<P>)),
   ]
 }
@@ -141,7 +141,7 @@ async fn accept_tcp(
   })
 }
 
-async fn op_accept(
+async fn op_net_accept(
   state: Rc<RefCell<OpState>>,
   args: AcceptArgs,
   _: (),
@@ -193,7 +193,7 @@ async fn receive_udp(
   })
 }
 
-async fn op_datagram_receive(
+async fn op_dgram_recv(
   state: Rc<RefCell<OpState>>,
   args: ReceiveArgs,
   zero_copy: ZeroCopyBuf,
@@ -214,7 +214,7 @@ struct SendArgs {
   transport_args: ArgsEnum,
 }
 
-async fn op_datagram_send<NP>(
+async fn op_dgram_send<NP>(
   state: Rc<RefCell<OpState>>,
   args: SendArgs,
   zero_copy: ZeroCopyBuf,
@@ -282,7 +282,7 @@ pub struct ConnectArgs {
   transport_args: ArgsEnum,
 }
 
-pub async fn op_connect<NP>(
+pub async fn op_net_connect<NP>(
   state: Rc<RefCell<OpState>>,
   args: ConnectArgs,
   _: (),
@@ -444,7 +444,7 @@ fn listen_udp(
   Ok((rid, local_addr))
 }
 
-fn op_listen<NP>(
+fn op_net_listen<NP>(
   state: &mut OpState,
   args: ListenArgs,
   _: (),
